# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing macros

1 January 1970 [Date] [date] 1 January 1970 [DATE]

[rfc2119]

bar [Foo] [foo]

qux qux qux

## References

### Informative References

[RFC2119]
  S. Bradner. Key words for use in RFCs to Indicate Requirement Levels. March 1997. Best Current Practice. URL: https://tools.ietf.org/html/rfc2119